import * as api from "aws-cdk-lib/aws-apigateway";
import * as acm from "aws-cdk-lib/aws-certificatemanager";
import * as iam from "aws-cdk-lib/aws-iam";
import * as lambda from "aws-cdk-lib/aws-lambda";
import * as logs from "aws-cdk-lib/aws-logs";
import * as route53 from "aws-cdk-lib/aws-route53";
import { Construct } from "constructs";
import { ApiGatewayToLambdaProps, CustomRoute } from "./rest-interface";
/**
 * Enhanced API Gateway to Lambda construct supporting both proxy and manual routing
 */
export declare class ApiGatewayToLambda extends Construct {
    readonly apiGateway: api.RestApi;
    readonly apiGatewayCloudWatchRole?: iam.Role;
    readonly apiGatewayLogGroup?: logs.LogGroup;
    readonly lambdaFunction: lambda.IFunction;
    readonly aRecord?: route53.ARecord;
    readonly certificate?: acm.ICertificate;
    readonly domain?: api.DomainName;
    readonly usagePlan?: api.UsagePlan;
    constructor(scope: Construct, id: string, props: ApiGatewayToLambdaProps);
    /**
     * Add custom routes to the API
     */
    private addCustomRoutes;
    /**
     * Setup CloudWatch logging
     */
    private setupLogging;
    /**
     * Setup custom domain with certificate and Route53 record
     */
    private setupCustomDomain;
    /**
     * Setup usage plan
     */
    private setupUsagePlan;
    /**
     * Add a custom route after construction (for dynamic route addition)
     */
    addRoute(route: CustomRoute): api.Method;
    /**
     * Get the API Gateway URL (useful for outputs)
     */
    get apiUrl(): string;
}
/**
 * Factory class for common API Gateway patterns
 */
export declare class ApiGatewayFactory {
    /**
     * Create a simple proxy API with common defaults
     */
    static createSimpleProxyApi(scope: Construct, id: string, lambdaFunction: lambda.IFunction, domainName?: string, hostedZone?: route53.IHostedZone): ApiGatewayToLambda;
    /**
     * Create a manual routes API with common defaults
     */
    static createManualRoutesApi(scope: Construct, id: string, primaryLambda: lambda.IFunction, routes: CustomRoute[], domainName?: string, hostedZone?: route53.IHostedZone): ApiGatewayToLambda;
    /**
     * Helper to create CustomRoute with API key requirement
     */
    static createRoute(path: string, method: string, handler: lambda.IFunction, requireApiKey?: boolean): CustomRoute;
}
