import * as apigatewayv2 from "aws-cdk-lib/aws-apigatewayv2";
import * as acm from "aws-cdk-lib/aws-certificatemanager";
import * as iam from "aws-cdk-lib/aws-iam";
import * as lambda from "aws-cdk-lib/aws-lambda";
import * as logs from "aws-cdk-lib/aws-logs";
import * as route53 from "aws-cdk-lib/aws-route53";
import { Construct } from "constructs";
import { WebSocketApiGatewayToLambdaProps, WebSocketRoute } from "./websocket-interface";
/**
 * Enhanced WebSocket API Gateway to Lambda construct
 */
export declare class WebSocketApiGatewayToLambda extends Construct {
    readonly webSocketApi: apigatewayv2.WebSocketApi;
    readonly webSocketStage: apigatewayv2.WebSocketStage;
    readonly apiGatewayCloudWatchRole?: iam.Role;
    readonly apiGatewayLogGroup?: logs.LogGroup;
    readonly lambdaFunction: lambda.IFunction;
    readonly aRecord?: route53.ARecord;
    readonly certificate?: acm.ICertificate;
    readonly domain?: apigatewayv2.DomainName;
    constructor(scope: Construct, id: string, props: WebSocketApiGatewayToLambdaProps);
    /**
     * Add custom routes to the WebSocket API
     */
    private addCustomRoutes;
    /**
     * Setup CloudWatch logging
     */
    private setupLogging;
    /**
     * Setup custom domain with certificate and Route53 record
     */
    private setupCustomDomain;
    /**
     * Add a custom route after construction (for dynamic route addition)
     */
    addRoute(route: WebSocketRoute): apigatewayv2.WebSocketRoute;
    /**
     * Get the WebSocket API URL (useful for outputs)
     */
    get webSocketUrl(): string;
}
/**
 * Factory class for common WebSocket API Gateway patterns
 */
export declare class WebSocketApiGatewayFactory {
    /**
     * Create a simple WebSocket API with common defaults
     */
    static createSimpleWebSocketApi(scope: Construct, id: string, lambdaFunction: lambda.IFunction, domainName?: string, hostedZone?: route53.IHostedZone): WebSocketApiGatewayToLambda;
    /**
     * Create a WebSocket API with custom routes
     */
    static createWebSocketApiWithRoutes(scope: Construct, id: string, defaultHandler: lambda.IFunction, routes: WebSocketRoute[], domainName?: string, hostedZone?: route53.IHostedZone): WebSocketApiGatewayToLambda;
    /**
     * Helper to create WebSocket route
     */
    static createRoute(routeKey: string, handler: lambda.IFunction, routeResponseSelectionExpression?: string): WebSocketRoute;
    /**
     * Create common WebSocket routes (connect, disconnect, default)
     */
    static createCommonRoutes(connectHandler: lambda.IFunction, disconnectHandler: lambda.IFunction, defaultHandler: lambda.IFunction): WebSocketRoute[];
}
